@@ -1,9 +1,8 @@
 from .libs import *
 from .other import *
+__version__ = "0.0.3"
 def show(img):
     plt.imshow(img)
-def save(name, img):
-    cv2.imwrite(name, np.array(img))
 def addrend(r1, r2, width, heigth):
     out = []
     for i in range(width):
@@ -17,4 +16,6 @@ def addrend(r1, r2, width, heigth):
                 out[len(out)-1].append(r1_)
             else:
                 out[len(out)-1].append(r1_)
-    return out
\ No newline at end of file
+    return out
+def __getattr__(attr):
+    raise pyvdl_error(f'attr: {attr} not found in module: pyvdl({__version__})')
\ No newline at end of file
